@@ -4,7 +4,7 @@ use strict;
 use Carp        qw[carp];
 use vars        qw[$FATAL $DEBUG $AUTOLOAD $VERSION];
 
-$VERSION    = '0.01';
+$VERSION    = '0.03';
 $FATAL      = 0;
 $DEBUG      = 0;
 
@@ -18,6 +18,12 @@ Object::Accessor
     $object = Object::Accessor->new;        # create object
 
     $bool   = $object->mk_accessors('foo'); # create accessors
+    $clone  = $object->mk_clone;            # create a clone of the original
+                                            # object without data
+    $bool   = $object->mk_flush;            # clean out all data    
+    
+    @list   = $object->ls_accessors;        # retrieves a list of all 
+                                            # accessors for this object
     
     $bar    = $object->foo('bar');          # set 'foo' to 'bar'
     $bar    = $object->foo();               # retrieve 'bar' again
@@ -62,10 +68,7 @@ inheritable.
 =cut 
 
 sub new {
-    my $class   = shift;
-    my $self    = bless {}, $class;
-
-    return $self;
+    return bless {}, $_[0];
 }
 
 =head2 $bool = $object->mk_accessors( @ACCESSORS );
@@ -88,10 +91,9 @@ section for details.
 =cut
 
 sub mk_accessors {
-    my $self = shift;
-    my @acc  = @_;
+    my $self = $_[0];
     
-    for my $acc (@acc) {
+    for my $acc (@_[1..$#_]) {
     
         ### already created apparently
         if( exists $self->{$acc} ) {
@@ -101,13 +103,62 @@ sub mk_accessors {
     
         _debug( "Creating accessor '$acc'");
     
-        ### initalize it 
+        ### explicitly vivify it, so that exists works in ls_accessors()
         $self->{$acc} = undef;
     }
     
     return 1;
 }    
 
+=head2 @list = $self->ls_accessors;
+
+Returns a list of accessors that are supported by the current object.
+The corresponding coderefs can be retrieved by passing this list one
+by one to the C<can> method.
+
+=cut
+
+sub ls_accessors {
+    return sort keys %{$_[0]};
+}    
+
+=head2 $clone = $self->mk_clone;
+
+Makes a clone of the current object, which will have the exact same
+accessors as the current object, but without the data stored in them.
+
+=cut
+
+sub mk_clone {
+    my $self    = $_[0];
+    my $class   = ref $self;
+    
+    my $clone   = $class->new;
+    
+    # copy the accessors from $self to $clone
+    $clone->mk_accessors( $self->ls_accessors );
+    
+    return $clone;
+}
+
+=head2 $bool = $self->mk_flush;
+
+Flushes all the data from the current object; all accessors will be
+set back to their default state of C<undef>.
+
+Returns true on success and false on failure.
+
+=cut
+
+sub mk_flush {
+    my $self = $_[0];
+
+    # set each accessor's data to undef
+    $self->$_( undef ) for $self->ls_accessors;
+    
+    return 1;
+}    
+
 =head2 $bool = $self->can( METHOD_NAME )
 
 This method overrides C<UNIVERAL::can> in order to provide coderefs to
@@ -129,8 +180,7 @@ See the C<SYNOPSIS> for more examples.
 
 ### custom 'can' as UNIVERSAL::can ignores autoload
 sub can {
-    my $self    = shift;
-    my $method  = shift;
+    my($self, $method) = @_;
     
     ### it's one of our regular methods
     if( $self->UNIVERSAL::can($method) ) {
@@ -145,7 +195,7 @@ sub can {
     }        
     
     ### we don't support it
-    _debug( "Can not '$method'" );
+    _debug( "Cannot '$method'" );
     return;
 }
 
@@ -155,24 +205,27 @@ sub DESTROY { 1 };
 ### use autoload so we can have per-object accessors, 
 ### not per class, as that is incorrect
 sub AUTOLOAD {
-    my $self    = shift;
-    my $method  = $AUTOLOAD;
-    $method     =~ s/.+:://g;
+    my $self    = $_[0];
+    my($method) = ($AUTOLOAD =~ /([^:']+$)/);
     
     unless( exists $self->{$method} ) {
         _error("No such accessor '$method'");
         return;
     }        
 
+    ### if there's more arguments than $self, then
+    ### replace the method called by the accessor.
     ### XXX implement rw vs ro accessors!
-    $self->{$method} = $_[0] if @_;
+    $self->{$method} = $_[1] if @_ > 1;
     
     return $self->{$method};
 }
 
 sub _debug { 
+    return unless $DEBUG;
+
     local $Carp::CarpLevel += 1;
-    carp(@_) if $DEBUG; 
+    carp(@_); 
 }
 
 sub _error { 
